==> knapster2_0.3.orig.tar.gz: knapster2-0.3/knapster2/napsterupload.h <==
/***************************************************************************
                          napsterupload.h  -  description
                             -------------------
    begin                : Fri Feb 4 2000
    copyright            : (C) 2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef NAPSTERUPLOAD_H
#define NAPSTERUPLOAD_H

#include <napstertransfer.h>

/**
  *@author John Donoghue
  */
class KSocket;
class KNAP_TransferPanel;

class NapsterUpload : public NapsterTransfer
{
  friend KNAP_TransferPanel;
   
  char _buffer[1024+2];

  int _sock;
  KSocket *sock;

//  bool type2;
private: 
   NapsterUpload(unsigned long ip,int port,const char *filename,const char *user,
         int speed,const char *dest);
   NapsterUpload(KSocket *,const char *filename,const char *user,long size,
	 int speed,const char *dest);
public:
   virtual ~NapsterUpload();
  // for uploads must give listener and start_sz
  // unless its a new upload
  bool start(int listen=-1,long start_sz=0);
private:
  virtual void run_method();

  bool upload();

  bool upload_new();

};

#endif

==> knapster2_0.5.orig.tar.gz: knapster2-0.5/knapster2/napsterupload.h <==
/***************************************************************************
                          napsterupload.h  -  description
                             -------------------
    begin                : Fri Feb 4 2000
    copyright            : (C) 2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef NAPSTERUPLOAD_H
#define NAPSTERUPLOAD_H

#include <napstertransfer.h>

/**
  *@author John Donoghue
  */
class KSocket;
class KNAP_TransferPanel;

class NapsterUpload : public NapsterTransfer
{
  friend class KNAP_TransferPanel;
   
  char _buffer[1024+2];

  int _sock;
  KSocket *sock;

//  bool type2;
private: 
   NapsterUpload(unsigned long ip,int port,const char *filename,const char *user,
         int speed,const char *dest);
   NapsterUpload(KSocket *,const char *filename,const char *user,long size,
	 int speed,const char *dest);
public:
   virtual ~NapsterUpload();
  // for uploads must give listener and start_sz
  // unless its a new upload
  bool start(int listen=-1,long start_sz=0);
private:
  virtual void run_method();

  bool upload();

  bool upload_new();

};

#endif
